[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
gEDA-cvs: gaf.git: branch: master updated (1.5.0-20080706-87-g6f42af2)
The branch, master has been updated
via 6f42af29cfe5c70203ce6b881d48d904c1bb0fc7 (commit)
from 0db6ea2341ce7cc8c631df75c4d3c30390590b29 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
=========
Summary
=========
gschem/src/o_grips.c | 15 ++++++---------
1 files changed, 6 insertions(+), 9 deletions(-)
=================
Commit Messages
=================
commit 6f42af29cfe5c70203ce6b881d48d904c1bb0fc7
Author: Bernd Jendrissek <bernd.jendrissek@xxxxxxxxx>
Date: Wed Aug 13 02:18:41 2008 +0100
o_grips_start(): Propagate world coords of pointers to o_grips_start_*()
The (unused) x and y parameters to o_grips_start_*() were previously
passed as 0, 0.
It seems obviously right to me to propagate w_x and w_y, even if the
target object pulls the pointer position out of w_current again, which
itself is quite evil.
:100644 100644 00ff6a1... 7ec9c01... M gschem/src/o_grips.c
=========
Changes
=========
commit 6f42af29cfe5c70203ce6b881d48d904c1bb0fc7
Author: Bernd Jendrissek <bernd.jendrissek@xxxxxxxxx>
Date: Wed Aug 13 02:18:41 2008 +0100
o_grips_start(): Propagate world coords of pointers to o_grips_start_*()
The (unused) x and y parameters to o_grips_start_*() were previously
passed as 0, 0.
It seems obviously right to me to propagate w_x and w_y, even if the
target object pulls the pointer position out of w_current again, which
itself is quite evil.
diff --git a/gschem/src/o_grips.c b/gschem/src/o_grips.c
index 00ff6a1..7ec9c01 100644
--- a/gschem/src/o_grips.c
+++ b/gschem/src/o_grips.c
@@ -483,15 +483,12 @@ int o_grips_start(GSCHEM_TOPLEVEL *w_current, int w_x, int w_y)
{
OBJECT *object;
int whichone;
- /* the x/y variables are currently not used by the start_* functions
- set them savely to 0*/
- int x=0, y=0;
if (w_current->draw_grips == FALSE) {
return(FALSE);
}
/* search if there is a grip on a selected object at (x,y) */
object = o_grips_search_world(w_current, w_x, w_y, &whichone);
if (object == NULL)
@@ -505,22 +502,22 @@ int o_grips_start(GSCHEM_TOPLEVEL *w_current, int w_x, int w_y)
switch(object->type) {
case(OBJ_ARC):
/* start the modification of a grip on an arc */
- o_grips_start_arc(w_current, object, x, y, whichone);
+ o_grips_start_arc(w_current, object, w_x, w_y, whichone);
return(TRUE);
case(OBJ_BOX):
/* start the modification of a grip on a box */
- o_grips_start_box(w_current, object, x, y, whichone);
+ o_grips_start_box(w_current, object, w_x, w_y, whichone);
return(TRUE);
case(OBJ_PICTURE):
/* start the modification of a grip on a picture */
- o_grips_start_picture(w_current, object, x, y, whichone);
+ o_grips_start_picture(w_current, object, w_x, w_y, whichone);
return(TRUE);
case(OBJ_CIRCLE):
/* start the modification of a grip on a circle */
- o_grips_start_circle(w_current, object, x, y, whichone);
+ o_grips_start_circle(w_current, object, w_x, w_y, whichone);
return(TRUE);
case(OBJ_LINE):
@@ -529,7 +526,7 @@ int o_grips_start(GSCHEM_TOPLEVEL *w_current, int w_x, int w_y)
case(OBJ_BUS):
/* identical for line/net/pin/bus */
/* start the modification of a grip on a line */
- o_grips_start_line(w_current, object, x, y, whichone);
+ o_grips_start_line(w_current, object, w_x, w_y, whichone);
return(TRUE);
default:
_______________________________________________
@@ -483,15 +483,12 @@ int o_grips_start(GSCHEM_TOPLEVEL *w_current, int w_x, int w_y)
return(FALSE);
}
- /* search if there is a grip on a selected object at (x,y) */
+ /* search if there is a grip on a selected object at (w_x,w_y) */
object = o_grips_search_world(w_current, w_x, w_y, &whichone);
if (object == NULL)
geda-cvs mailing list
geda-cvs@xxxxxxxxxxxxxx
http://www.seul.org/cgi-bin/mailman/listinfo/geda-cvs